@@ -61,7 +61,7 @@ mod tests {
     #[test]
     fn escape_test2() {
 
-        let md = "*escaped\\* `\\not escaped` \\`escaped`".to_string();
+        let md = "*escaped\\* `\\not escaped\\` \\`escaped`".to_string();
         let html = "<p>*escaped&#42; <code class=\"short\">\\not escaped</code> &#96;escaped`</p>"; // ..later!
 
         assert_eq!(
@@ -158,7 +158,7 @@ mod tests {
         use std::fs::File;
         use std::io::{Read, Write};
 
-        let mut f = File::open("README.md").unwrap();
+        let mut f = File::open("0303.md").unwrap();
         let mut st = String::new();
 
         f.read_to_string(&mut st).unwrap();
