@@ -31,6 +31,18 @@ pub fn render_code_spans(content: &Vec<u16>) -> Vec<u16> {
             is_inside_code = !is_inside_code;
         }
 
+        // `\ backslash at the end! \` -> valid code span
+        else if *c == BACKSLASH_ESCAPE_MARKER && ind + 1 < content.len() && content[ind + 1] == u16::MAX - U16_BACKTICK && is_inside_code {
+            result.push(vec![
+                into_v16("<code class=\"short\">"),
+                undo_backslash_escape(&content[last_index..ind].to_vec()),
+                into_v16("\\</code>"),
+            ].concat());
+
+            last_index = ind + 2;
+            is_inside_code = false;
+        }
+
     }
 
     if is_inside_code {
