@@ -2,7 +2,7 @@ use crate::consts::*;
 use crate::markdown::icon::get_icon;
 use crate::markdown::line::{Line, LineType};
 use crate::markdown::colors::COLOR_NAMES;
-use crate::utils::{get_bracket_end_index, lowercase, into_v16};
+use crate::utils::*;
 use std::str::FromStr;
 
 
@@ -87,7 +87,7 @@ pub fn is_tag(content: &Vec<u16>, index: usize) -> bool {
 fn parse_tag(content: &Vec<u16>, index: usize) -> Result<Vec<u16>, ()> {
 
     let end_index = get_bracket_end_index(content, index + 1).unwrap();
-    let content = content[index + 2..end_index].iter().filter(|c| *c != &U16_SPACE).map(|c| lowercase(*c)).collect::<Vec<u16>>();
+    let content = lowercase_and_remove_spaces(&content[index + 2..end_index]);
 
     if content.len() == 0 {
         return Err(());
