@@ -2,7 +2,7 @@ use crate::consts::*;
 
 
 pub fn into_v16(s: &str) -> Vec<u16> {
-    String::from(s).encode_utf16().collect()
+    String::from(s).encode_utf16().filter(|c| *c != 13).collect()
 }
 
 
@@ -67,6 +67,11 @@ pub fn get_parenthesis_end_index(v: &Vec<u16>, index: usize) -> Option<usize> {
 }
 
 
+pub fn get_curly_brace_end_index(v: &Vec<u16>, index: usize) -> Option<usize> {
+    get_partner_index(v, index, U16_LEFT_CURLY_BRACE, U16_RIGHT_CURLY_BRACE)
+}
+
+
 fn get_partner_index(v: &Vec<u16>, begin_index: usize, s: u16, p: u16) -> Option<usize> {
 
     let mut stack: i32 = 0;
@@ -115,6 +120,16 @@ pub fn lowercase(c: u16) -> u16 {
 }
 
 
+pub fn is_alphabet(c: u16) -> bool {
+    U16_BIG_A <= c && c <= U16_BIG_Z || U16_SMALL_A <= c && c <= U16_SMALL_Z
+}
+
+
+pub fn lowercase_and_remove_spaces(content: &[u16]) -> Vec<u16> {
+    content.iter().filter(|c| *c != &U16_SPACE).map(|c| lowercase(*c)).collect::<Vec<u16>>()
+}
+
+
 #[cfg(test)]
 mod tests {
 
